# StreetResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**usrn** | **float** |  | 
**street_descriptor** | **str** |  | 
**area** | **str** |  | 
**town** | **str** |  | 
**authority** | **str** |  | 
**authority_swa_code** | **str** |  | 
**road_category** | **float** | DEPRECATED | 
**reinstatement_types** | [**list[ReinstatementTypeDetails]**](ReinstatementTypeDetails.md) |  | 
**traffic_sensitive** | **bool** |  | 
**primary_notice_authorities** | [**list[PrimaryNoticeAuthority]**](PrimaryNoticeAuthority.md) |  | 
**interest_authorities** | [**list[InterestAuthority]**](InterestAuthority.md) |  | 
**additional_special_designations_response** | [**list[AdditionalSpecialDesignationsResponse]**](AdditionalSpecialDesignationsResponse.md) |  | 
**street_line** | **AllOfStreetResponseStreetLine** |  | [optional] 
**street_centre_point** | **AllOfStreetResponseStreetCentrePoint** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

